package status

import (
	"context"
	"gitea.pena/PenaSide/treasurer/internal/repository"

	"gitea.pena/PenaSide/treasurer/internal/errors"
	"gitea.pena/PenaSide/treasurer/internal/models"
	"go.uber.org/zap"
)

type Deps struct {
	Logger            *zap.Logger
	PaymentRepository *repository.PaymentRepository
}

type Service struct {
	logger            *zap.Logger
	paymentRepository *repository.PaymentRepository
}

func New(deps Deps) (*Service, errors.Error) {
	if deps.Logger == nil {
		return nil, errors.NewWithMessage("logger is nil on <NewStatusService>", errors.ErrInvalidArgs)
	}

	if deps.PaymentRepository == nil {
		return nil, errors.NewWithMessage("PaymentRepository is nil on <NewStatusService>", errors.ErrInvalidArgs)
	}

	return &Service{
		logger:            deps.Logger,
		paymentRepository: deps.PaymentRepository,
	}, nil
}

func (s *Service) SetStatusCanceled(ctx context.Context, paymentID string) (*models.Payment, errors.Error) {
	payment, err := s.paymentRepository.SetPaymentStatus(ctx, paymentID, models.PaymentStatusCanceled)
	if err != nil {
		s.logger.Error("failed to set payment status on <SetStatusCanceled> of <StatusService>", zap.Error(err))
		return nil, err
	}

	return payment, nil
}

func (s *Service) SetStatusSuccess(ctx context.Context, paymentID string) (*models.Payment, errors.Error) {
	payment, err := s.paymentRepository.SetPaymentStatus(ctx, paymentID, models.PaymentStatusSuccessfully)
	if err != nil {
		s.logger.Error("failed to set payment status on <SetStatusSuccess> of <StatusService>", zap.Error(err))
		return nil, err
	}

	return payment, nil
}

func (s *Service) SetStatusWaiting(ctx context.Context, paymentID string) (*models.Payment, errors.Error) {
	payment, err := s.paymentRepository.SetPaymentStatus(ctx, paymentID, models.PaymentStatusWaiting)
	if err != nil {
		s.logger.Error("failed to set payment status on <SetStatusWaiting> of <StatusService>", zap.Error(err))
		return nil, err
	}

	return payment, nil
}

func (s *Service) SetStatusRefund(ctx context.Context, paymentID string) (*models.Payment, errors.Error) {
	payment, err := s.paymentRepository.SetPaymentStatus(ctx, paymentID, models.PaymentStatusRefund)
	if err != nil {
		s.logger.Error("failed to set payment status on <SetStatusRefund> of <StatusService>", zap.Error(err))
		return nil, err
	}

	return payment, nil
}
